'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _unmutableLite = require('unmutable-lite');

var _Utils = require('./Utils');

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var DEFAULT_CONFIG = {
    columnLimit: 'Y',
    valueInputOption: 'RAW'
};

var SheetsRequester = function SheetsRequester() {
    var _this = this;

    var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _classCallCheck(this, SheetsRequester);

    this.clone = function () {
        var newConfig = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
        return new SheetsRequester(_extends({}, _this._config, newConfig));
    };

    this.sheet = function (sheet) {
        return _this.clone({ sheet: sheet });
    };

    this.keys = function () {
        var _config = _this._config,
            columnLimit = _config.columnLimit,
            sheet = _config.sheet,
            spreadsheetId = _config.spreadsheetId;


        if (!sheet) {
            throw new Error('sheet name must be set (use SheetsRequester.sheet(sheet: string))');
        }

        return (0, _Utils.gapiSheetValues)().get({
            spreadsheetId: spreadsheetId,
            range: sheet + '!A1:' + columnLimit + '1'
        }).then(function (response) {
            return (0, _unmutableLite.Wrap)(response).getIn(['result', 'values', 0]).done();
        }, function (error) {
            return Promise.reject(error);
        });

        // todo error if id is not a key?
    };

    this.list = function () {
        var _config2 = _this._config,
            columnLimit = _config2.columnLimit,
            sheet = _config2.sheet,
            spreadsheetId = _config2.spreadsheetId;


        if (!sheet) {
            throw new Error('sheet name must be set (use SheetsRequester.sheet(sheet: string))');
        }

        return (0, _Utils.gapiSheetValues)().get({
            spreadsheetId: spreadsheetId,
            range: sheet + '!A1:' + columnLimit,
            valueRenderOption: "UNFORMATTED_VALUE"
        }).then(function (response) {
            var values = (0, _unmutableLite.Wrap)(response).getIn(['result', 'values']);
            var keys = values.first().done();
            return values.rest().done() // flip this once map() is in unmutable-lite
            .map(function (ii) {
                return (0, _Utils.fromSheetRow)(ii, keys);
            });
        }, function (error) {
            return Promise.reject(error);
        });
    };

    this.push = function (item) {
        var _config3 = _this._config,
            columnLimit = _config3.columnLimit,
            sheet = _config3.sheet,
            spreadsheetId = _config3.spreadsheetId,
            valueInputOption = _config3.valueInputOption;


        if (!sheet) {
            throw new Error('sheet name must be set (use SheetsRequester.sheet(sheet: string))');
        }

        return _this.keys().then(function (keys) {
            var row = (0, _Utils.toSheetRow)((0, _Utils.addNewId)(item), keys);
            return (0, _Utils.gapiSheetValues)().append({
                spreadsheetId: spreadsheetId,
                range: sheet + '!A1:' + columnLimit,
                valueInputOption: valueInputOption,
                resource: {
                    values: [row]
                }
            });
        });
        //.then(() => this.list());
    };

    this._config = _extends({}, DEFAULT_CONFIG, config);
};

exports.default = SheetsRequester;