'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.generateId = exports.addNewId = exports.toSheetRow = exports.fromSheetRow = exports.fromSheetValue = exports.toSheetValue = exports.gapiSheetValues = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _unmutableLite = require('unmutable-lite');

var gapiSheetValues = exports.gapiSheetValues = function gapiSheetValues() {
    var values = (0, _unmutableLite.Wrap)(gapi).getIn(['client', 'sheets', 'spreadsheets', 'values']).done();

    if (!values) {
        throw new Error('gapi global variable (api v4) and gapi.sheets must be loaded');
    }
    return values;
};

var toSheetValue = exports.toSheetValue = function toSheetValue(value) {
    if (['number', 'boolean', 'string'].indexOf(typeof value === 'undefined' ? 'undefined' : _typeof(value)) === -1) {
        return '"' + JSON.stringify(value) + '"';
    }
    if (typeof value === "string" && value.slice(0, 1) === '"') {
        return '"' + value + '"';
    }
    return value;
};

var fromSheetValue = exports.fromSheetValue = function fromSheetValue(value) {
    if (typeof value !== "string") {
        return value;
    }
    if (value.slice(0, 1) === '"') {
        return JSON.parse(value.slice(1, -1));
    }
    return value;
};

var fromSheetRow = exports.fromSheetRow = function fromSheetRow(row, keys) {
    return row.reduce(function (obj, value, key) {
        var columnName = keys[key];
        if (columnName) {
            obj[columnName] = fromSheetValue(value);
        }
        return obj;
    }, {});
};

var toSheetRow = exports.toSheetRow = function toSheetRow(obj, keys) {
    return keys.map(function (ii) {
        return toSheetValue(obj[ii]);
    });
};

var addNewId = exports.addNewId = function addNewId(obj) {
    return _extends({}, obj, {
        id: generateId()
    });
};

var generateId = exports.generateId = function generateId() {
    return Math.random().toString(36).substr(2) + new Date().valueOf().toString(36);
};